app_preference library
A library to store and retrieve app preferences.
Classes
-
AppPreference<
T> - An observable value holder that can be used to store and retrieve app preferences.
Mixins
Extensions
- AppPreferenceEnsuredExtension on AP
- Extension methods for AppPreference All methods here works on derived type of AppPreference